@@ -37,6 +37,8 @@ create_transposed_data <- function(x, n = 50){
   #x <- indicator_dataset
 
   nr <- nrow(x)
+  namesdfr12 <- paste0("X", 1:n) #generated names for dataset useful later in the code
+
   dat11 <- x %>% select(-1) %>% split(rep(1:ceiling(nr/n), each=n, length.out=nr)) #list
   dat11[length(dat11)] <- NULL
 
@@ -45,8 +47,12 @@ create_transposed_data <- function(x, n = 50){
     #i <- 1
 
     if(!exists("dfr12")){
-      dfr12 <- dat11[i] %>% as.data.frame() %>% t() %>% as_tibble(.name_repair = "universal", verbose =F) } else {
-        dfr12 <- dat11[i] %>% as.data.frame() %>% t() %>% as_tibble(.name_repair = "universal", verbose =F) %>% bind_rows(dfr12)
+      dfr12 <- dat11[i] %>% as.data.frame() %>% t() %>% as_tibble(.name_repair = "minimal", verbose =F)
+      names(dfr12) <- namesdfr12
+      } else {
+        dfr12 <- dat11[i] %>% as.data.frame() %>% t() %>% as_tibble(.name_repair = "minimal", verbose =F)
+          names(dfr12) <- namesdfr12
+          dfr12 <- dfr12 %>% bind_rows(dfr12)
       }
 
   }
